import {HttpMethod, Route, StatusCodes} from 'org.crazydoctor.expressts';
import {Request, Response} from 'express';
import { ClassMapEntity, Sources } from '../sources/Sources';
import fs from 'fs';

class GetClass extends Route {
	private processClass(cls: ClassMapEntity): { Class: ClassMapEntity, ClassSource: string } {
		const srcPath = cls.filePath;
		const source = fs.readFileSync(`${Sources.sourcesCopyPath}/${srcPath}`, { encoding: 'utf8' }).toString();
		return { Class: cls, ClassSource: source };
	}

	protected action = (req: Request, res: Response): any => {
		const className = req.params.className;
		const cls: ClassMapEntity | null = Sources.findClass(className);
		if(!cls)
			res.status(StatusCodes.NOT_FOUND).send(`Class '${className}' not found.`);
		else
			res.status(StatusCodes.OK).render('class', Object.assign(this.processClass(cls), { template: 'class', title: `Class: ${className}`, ClassList: Sources.getShortenedClassMap(), RepoNames: Sources.getRepoNames() }));
	};
	protected method = HttpMethod.GET;
	protected order = 1;
	protected route = '/class/:className';
}

export default GetClass;